@@ -1,5 +1,4 @@
 from copy import deepcopy
-from functools import partial
 from StringIO import StringIO
 from datetime import date, datetime
 from collections import MutableMapping
@@ -55,9 +54,9 @@ class APIObject(object):
         try:
             return self.pk()
         except AttributeError:
-            return None
+            pass
 
-    def url(self, base_url=None, relative_url=None, *args, **kwargs):
+    def url(self, base_url=None, relative_url=None):
         """
         Generates an absolute url to a model's instance in the API.
         """
@@ -72,11 +71,11 @@ class APIObject(object):
                 'pk': self._safe_pk(),
                 })
 
-    def list_url(self, *args, **kwargs):
+    def list_url(self):
         """
         Generates an absolute url to a list of the model's type on the API.
         """
-        return self.url(relative_url=self.Meta.relative_list_url, *args, **kwargs)
+        return self.url(relative_url=self.Meta.relative_list_url)
 
     def _get_pk_of_attr(self, attr, default=None):
         """
@@ -293,6 +292,7 @@ class Cache(MutableMapping):
 
     def __setitem__(self, key, value):
         self.store[key] = value
+    set = __setitem__
 
     def __getitem__(self, item):
         """
@@ -313,6 +313,9 @@ class Cache(MutableMapping):
     def __len__(self):
         return len(self.store)
 
+    def has_cached(self, item):
+        return True if self.store.has_key(item) and self.store[item] is not None else False
+
     def activate(self):
         self.cache_responses = True
 
