@@ -1,4 +1,4 @@
-from base_models import APIObject, AssemblaObject, Cache
+from base_models import APIObject, AssemblaObject
 from error import AssemblaError
 
 
@@ -37,7 +37,7 @@ class API(APIObject):
                 initialise_with=data[1]
                 ) for data in raw_data
             ]
-    
+
     def spaces(self):
         """
         Returns the spaces available to the user
@@ -87,11 +87,13 @@ class Space(AssemblaObject):
         the API and returned.
         """
         child_func = getattr(self, '_get_{0}'.format(child))
-        if not self.cache.cache_responses:
+        if self.cache.cache_responses:
+            if not self.cache.has_cached(child):
+                self.cache.set(child, child_func())
+            return self.cache.get(child)
+        else:
             return child_func()
-        if not self.cache.get(child):
-            self.cache[child] = child_func()
-        return self.cache.get(child)
+
 
     def _get_milestones(self):
         """
